@@ -15,6 +15,7 @@ var encoder_8h =
     [ "VarBasedPartitionInfo", "structVarBasedPartitionInfo.html", "structVarBasedPartitionInfo" ],
     [ "AV1EncRowMultiThreadSync", "structAV1EncRowMultiThreadSync.html", "structAV1EncRowMultiThreadSync" ],
     [ "AV1EncRowMultiThreadInfo", "structAV1EncRowMultiThreadInfo.html", "structAV1EncRowMultiThreadInfo" ],
+    [ "PrimaryMultiThreadInfo", "structPrimaryMultiThreadInfo.html", "structPrimaryMultiThreadInfo" ],
     [ "MultiThreadInfo", "structMultiThreadInfo.html", "structMultiThreadInfo" ],
     [ "ForceIntegerMVInfo", "structForceIntegerMVInfo.html", "structForceIntegerMVInfo" ],
     [ "MBMIExtFrameBufferInfo", "structMBMIExtFrameBufferInfo.html", "structMBMIExtFrameBufferInfo" ],
@@ -31,13 +32,16 @@ var encoder_8h =
     [ "EncSegmentationInfo", "structEncSegmentationInfo.html", "structEncSegmentationInfo" ],
     [ "TimeStamps", "structTimeStamps.html", "structTimeStamps" ],
     [ "CoeffBufferPool", "structCoeffBufferPool.html", "structCoeffBufferPool" ],
+    [ "AV1_COMP_DATA", "structAV1__COMP__DATA.html", "structAV1__COMP__DATA" ],
     [ "AV1_PRIMARY", "structAV1__PRIMARY.html", "structAV1__PRIMARY" ],
     [ "AV1_COMP", "structAV1__COMP.html", "structAV1__COMP" ],
     [ "EncodeFrameInput", "structEncodeFrameInput.html", null ],
     [ "EncodeFrameParams", "structEncodeFrameParams.html", "structEncodeFrameParams" ],
     [ "AV1EncoderConfig", "encoder_8h.html#ae37f210917b9733abc7ca81445427d71", null ],
     [ "InterModesInfo", "encoder_8h.html#a9f8c3abfb05222c315bd3051a142c718", null ],
+    [ "PrimaryMultiThreadInfo", "encoder_8h.html#a1e0a95f3ba85551b4280ef86a45235bb", null ],
     [ "MultiThreadInfo", "encoder_8h.html#a371e7dff2f6e26ebcb3ac61fd872a21f", null ],
+    [ "AV1_COMP_DATA", "encoder_8h.html#a4a823cfecd8aa8c27bd6670df6ad9713", null ],
     [ "AV1_PRIMARY", "encoder_8h.html#a9af93120431b9d96ca04670151ea562c", null ],
     [ "AV1_COMP", "encoder_8h.html#a0207efa57c443f3ff9e157c22c532b5f", null ],
     [ "EncodeFrameInput", "encoder_8h.html#a246db68993252fe81c1e5a911575efb4", null ],
@@ -49,7 +53,7 @@ var encoder_8h =
       [ "COST_UPD_OFF", "encoder_8h.html#a03bce75164cb579c775759205ed26055a6f0f4239b7fc9f98980631093f885cc0", null ]
     ] ],
     [ "av1_receive_raw_frame", "group__high__level__algo.html#ga681c10fbb05a4c91b4536107f3342c37", null ],
-    [ "av1_get_compressed_data", "group__high__level__algo.html#gae1ceea4df4210e2464865ea90d5aa9ca", null ],
+    [ "av1_get_compressed_data", "group__high__level__algo.html#ga4017ec9e9cfd7bd461775266c80ff46d", null ],
     [ "av1_encode", "group__high__level__algo.html#gad4f93a0174051f16f9010f332f6c9bc7", null ],
     [ "has_no_stats_stage", "group__two__pass__algo.html#ga737bbff8d05e931b73b4321a0fa35d0e", null ]
 ];
\ No newline at end of file
