@@ -1,6 +1,92 @@
 var group__aom__encoder =
 [
+    [ "aom_external_partition.h", "aom__external__partition_8h.html", null ],
     [ "aomcx.h", "aomcx_8h.html", null ],
+    [ "aom_ext_part_config", "structaom__ext__part__config.html", [
+      [ "superblock_size", "structaom__ext__part__config.html#afea4a08073da755d626dc7f7a308922c", null ]
+    ] ],
+    [ "aom_partition_features_before_none", "structaom__partition__features__before__none.html", [
+      [ "f", "structaom__partition__features__before__none.html#a3e68a4613b294ec8ee5a5dbda67d0686", null ],
+      [ "f_part2", "structaom__partition__features__before__none.html#ab3f2b4befa941b58b378e2cd8ec401fd", null ]
+    ] ],
+    [ "aom_partition_features_none", "structaom__partition__features__none.html", [
+      [ "f", "structaom__partition__features__none.html#ab342e40d34aa67f83e103307f01ddc08", null ],
+      [ "f_terminate", "structaom__partition__features__none.html#a56d6654d19102937664def116a85d5f5", null ]
+    ] ],
+    [ "aom_partition_features_split", "structaom__partition__features__split.html", [
+      [ "f_terminate", "structaom__partition__features__split.html#a91689fc7a77585043a1f688fe7d91454", null ],
+      [ "f_prune_rect", "structaom__partition__features__split.html#a950d55955a97e530379a0aeed441196b", null ]
+    ] ],
+    [ "aom_partition_features_rect", "structaom__partition__features__rect.html", [
+      [ "f", "structaom__partition__features__rect.html#a439756ac5789b7b4a4a372c71097632c", null ]
+    ] ],
+    [ "aom_partition_features_ab", "structaom__partition__features__ab.html", [
+      [ "f", "structaom__partition__features__ab.html#a6567b2854b58057776c35b0e6363fe22", null ]
+    ] ],
+    [ "aom_sb_tpl_features", "structaom__sb__tpl__features.html", [
+      [ "available", "structaom__sb__tpl__features.html#a8228b46700a21ab4046492f633312904", null ],
+      [ "tpl_unit_length", "structaom__sb__tpl__features.html#af749988972e8c01fb60f721c44a5c25a", null ],
+      [ "num_units", "structaom__sb__tpl__features.html#a82bfdcc31c8475f26b32f7abb22cd617", null ],
+      [ "intra_cost", "structaom__sb__tpl__features.html#af4010c9b8928177fbf5d5843c148a6c0", null ],
+      [ "inter_cost", "structaom__sb__tpl__features.html#ac3943a8049b841846176edd4e0debd1d", null ],
+      [ "mc_dep_cost", "structaom__sb__tpl__features.html#ab03f2248d937ac7a288144e21fc0efc1", null ]
+    ] ],
+    [ "aom_sb_simple_motion_features", "structaom__sb__simple__motion__features.html", [
+      [ "unit_length", "structaom__sb__simple__motion__features.html#a7aa12bec07b36b03a28cfb05c8c1e3aa", null ],
+      [ "num_units", "structaom__sb__simple__motion__features.html#a2f95654f86af8d033f746850c9464e27", null ],
+      [ "block_sse", "structaom__sb__simple__motion__features.html#affcb678b566cc457b8350d918b9e4348", null ],
+      [ "block_var", "structaom__sb__simple__motion__features.html#a687222319c4539eb4a0c0590040a7d77", null ]
+    ] ],
+    [ "aom_sb_features", "structaom__sb__features.html", [
+      [ "motion_features", "structaom__sb__features.html#a8306feb95faafa28db0969b28df8a44c", null ],
+      [ "tpl_features", "structaom__sb__features.html#a6ed9e89e84705ecf2b57f4675c6fe7a5", null ]
+    ] ],
+    [ "aom_partition_features", "structaom__partition__features.html", [
+      [ "id", "structaom__partition__features.html#a4731d83b9b04f9cfd3893f4f1dbdd080", null ],
+      [ "before_part_none", "structaom__partition__features.html#abbf59077401dce7ac4d055514ad80301", null ],
+      [ "after_part_none", "structaom__partition__features.html#a57a8ca171132cd4a77632592c7c41192", null ],
+      [ "after_part_split", "structaom__partition__features.html#adf54cf17eaf05c05d86c9193094a1f50", null ],
+      [ "after_part_rect", "structaom__partition__features.html#a15a457204ef86ff3263440bec4ddc948", null ],
+      [ "after_part_ab", "structaom__partition__features.html#a211821af78f8bdaf62a18c235a916093", null ],
+      [ "sb_features", "structaom__partition__features.html#adb8aa70a30508890279af5b16e93b28a", null ],
+      [ "mi_row", "structaom__partition__features.html#aaee6343bfdea3e083deb4b302ece6a50", null ],
+      [ "mi_col", "structaom__partition__features.html#aed1b95e9c03152afc09f5bf181cb43f2", null ],
+      [ "frame_width", "structaom__partition__features.html#a67d6bcec5129ee4685c702fb68ceea4f", null ],
+      [ "frame_height", "structaom__partition__features.html#ad4f1272c0b5afaedec168eabdfbfa0c5", null ],
+      [ "block_size", "structaom__partition__features.html#a8051104747244a265e72d6f0644374df", null ]
+    ] ],
+    [ "aom_partition_decision", "structaom__partition__decision.html", [
+      [ "is_final_decision", "structaom__partition__decision.html#a0382eea62fc1c2d512f39204975c2e4a", null ],
+      [ "num_nodes", "structaom__partition__decision.html#a538dd9c4e764cd3ea4d2668271873c89", null ],
+      [ "partition_decision", "structaom__partition__decision.html#ad92afb344cddb69b412464dda7244ac0", null ],
+      [ "current_decision", "structaom__partition__decision.html#add0b1ea35484e23edf1b8f13217ae8b0", null ],
+      [ "terminate_partition_search", "structaom__partition__decision.html#a2679a5fbc948af8c30a122dc1ce6a557", null ],
+      [ "partition_none_allowed", "structaom__partition__decision.html#a86bc8ec9886ad34550a48fdc62c352ac", null ],
+      [ "partition_rect_allowed", "structaom__partition__decision.html#a5332dca7476c9ded1e4f6faee1dd6cc8", null ],
+      [ "do_rectangular_split", "structaom__partition__decision.html#abe1fc1a23dd2d7a6cb2eff778b8ee3ba", null ],
+      [ "do_square_split", "structaom__partition__decision.html#a076cbd55af72c5eaad9863139a8182b9", null ],
+      [ "prune_rect_part", "structaom__partition__decision.html#af2410511da3a9d5172d40d05de5565b4", null ],
+      [ "horza_partition_allowed", "structaom__partition__decision.html#a682ec9f4a54f9e1e52731e09b8ff5f79", null ],
+      [ "horzb_partition_allowed", "structaom__partition__decision.html#a41b8263d21c799573aa1ce1aef3edec8", null ],
+      [ "verta_partition_allowed", "structaom__partition__decision.html#a15374b52d4a5c940a091d7b77b7abc9b", null ],
+      [ "vertb_partition_allowed", "structaom__partition__decision.html#a3c0c209683759bdae0daf4e2337ba664", null ],
+      [ "partition_horz4_allowed", "structaom__partition__decision.html#ad41b933b59f08ff0f83528e5ee85a64a", null ],
+      [ "partition_vert4_allowed", "structaom__partition__decision.html#a2e00d6cfd7c3ef2454224024b5f35c41", null ]
+    ] ],
+    [ "aom_partition_stats", "structaom__partition__stats.html", [
+      [ "rate", "structaom__partition__stats.html#ab01c959aac5c69c5bb801598171360a9", null ],
+      [ "dist", "structaom__partition__stats.html#a6855e7cc86f7c00d7358d94b6f096224", null ],
+      [ "rdcost", "structaom__partition__stats.html#a88f68df6e27aa77485f2dade868634f9", null ]
+    ] ],
+    [ "aom_ext_part_funcs", "structaom__ext__part__funcs.html", [
+      [ "create_model", "structaom__ext__part__funcs.html#a53c7c5dcc3b0cc4ac165dd0366992f86", null ],
+      [ "send_features", "structaom__ext__part__funcs.html#ae3bb6fb4a43da49e22a36a8f67160272", null ],
+      [ "get_partition_decision", "structaom__ext__part__funcs.html#a0df62dada4f6083dfa4557f0bebb16c9", null ],
+      [ "send_partition_stats", "structaom__ext__part__funcs.html#afeeb0b64960dfd54d116a41ad6dbaba0", null ],
+      [ "delete_model", "structaom__ext__part__funcs.html#a00b5dea45726cf43a0407cbd7d09b907", null ],
+      [ "decision_mode", "structaom__ext__part__funcs.html#a4710159f9ee2717f81b495e0c72f7b95", null ],
+      [ "priv", "structaom__ext__part__funcs.html#a38bf7bd45873982823515d0dff2ec81c", null ]
+    ] ],
     [ "aom_roi_map", "structaom__roi__map.html", [
       [ "roi_map", "structaom__roi__map.html#a7d12a1d1074e33fd32077d568e4304d6", null ],
       [ "rows", "structaom__roi__map.html#a70a76ce19292cbdf943a5658b9601fdd", null ],
@@ -37,6 +123,18 @@ var group__aom__encoder =
       [ "ref_idx", "structaom__svc__ref__frame__config.html#ae6f0dece96f18986127eb6c2ee66c210", null ],
       [ "refresh", "structaom__svc__ref__frame__config.html#ab2a4596eadeaf5b7730588367918beda", null ]
     ] ],
+    [ "aom_svc_ref_frame_comp_pred", "structaom__svc__ref__frame__comp__pred.html", [
+      [ "use_comp_pred", "structaom__svc__ref__frame__comp__pred.html#ab577b1cb23becd2e053da0dac4175a0f", null ]
+    ] ],
+    [ "AOM_EXT_PART_ABI_VERSION", "group__aom__encoder.html#ga5a44302260efb45ebf560f7fb0b4352b", null ],
+    [ "AOM_EXT_PART_SIZE_DIRECT_SPLIT", "group__aom__encoder.html#gae5ea047136d781f9d7eb4c342121b41a", null ],
+    [ "AOM_EXT_PART_SIZE_PRUNE_PART", "group__aom__encoder.html#ga29427094de00e8d1883207afcc28b22c", null ],
+    [ "AOM_EXT_PART_SIZE_PRUNE_NONE", "group__aom__encoder.html#gaf8d9d8acde0c4a982e80d1dec78ba8ad", null ],
+    [ "AOM_EXT_PART_SIZE_TERM_NONE", "group__aom__encoder.html#ga28cc21cd9c9fc1f02818e90772a0baf6", null ],
+    [ "AOM_EXT_PART_SIZE_TERM_SPLIT", "group__aom__encoder.html#gaff93c6de790dccd2faaa6556130d0b3b", null ],
+    [ "AOM_EXT_PART_SIZE_PRUNE_RECT", "group__aom__encoder.html#ga6ee5804fef84710679f46bb77895aa90", null ],
+    [ "AOM_EXT_PART_SIZE_PRUNE_AB", "group__aom__encoder.html#gae2d6be6f94a6e0342f990d45826f9d4e", null ],
+    [ "AOM_EXT_PART_SIZE_PRUNE_4_WAY", "group__aom__encoder.html#ga23f13860556f8879c2cef2565b8182a8", null ],
     [ "AOM_EFLAG_NO_REF_LAST", "group__aom__encoder.html#gae272ed6e69ae2a12993565e8176d004b", null ],
     [ "AOM_EFLAG_NO_REF_LAST2", "group__aom__encoder.html#ga50c2560ca6670298cfc614ecae96a391", null ],
     [ "AOM_EFLAG_NO_REF_LAST3", "group__aom__encoder.html#gaa4bc8ae2b977b73f0ef57ba428ca1d2c", null ],
@@ -56,6 +154,27 @@ var group__aom__encoder =
     [ "AOM_MAX_LAYERS", "group__aom__encoder.html#ga3589babe0100b5bf7dc7167675014608", null ],
     [ "AOM_MAX_SS_LAYERS", "group__aom__encoder.html#ga9f3d7cfaa6290b207c0ce360ed63ae45", null ],
     [ "AOM_MAX_TS_LAYERS", "group__aom__encoder.html#ga5ecd6f60f02c807e0de37df7b7278f4e", null ],
+    [ "aom_ext_part_model_t", "group__aom__encoder.html#ga8ac829090566737c469a7147207e8855", null ],
+    [ "aom_ext_part_decision_mode_t", "group__aom__encoder.html#gaca3421fd8424ed3ab48704748a12c9d1", null ],
+    [ "aom_ext_part_config_t", "group__aom__encoder.html#ga88539c1f9e72d6ab6f8802ff265539dd", null ],
+    [ "aom_partition_features_before_none_t", "group__aom__encoder.html#ga45f71361ba7598dbb347d6f8de8f37b6", null ],
+    [ "aom_partition_features_none_t", "group__aom__encoder.html#gaeb906a5b059249c051cb0d2f853aff6c", null ],
+    [ "aom_partition_features_split_t", "group__aom__encoder.html#ga00f4961195d6d1d53c045d9675bb4d78", null ],
+    [ "aom_partition_features_rect_t", "group__aom__encoder.html#gad09f5b034137ba0981dd5f2dc075b27f", null ],
+    [ "aom_partition_features_ab_t", "group__aom__encoder.html#ga0713a9137d099e441bd6b7ed10be1b0d", null ],
+    [ "aom_sb_tpl_features_t", "group__aom__encoder.html#gadb34e02e5b029504370f99a886371710", null ],
+    [ "aom_sb_simple_motion_features_t", "group__aom__encoder.html#ga790f05ad7832f2614a13fd60bd3430fe", null ],
+    [ "aom_sb_features_t", "group__aom__encoder.html#gacfd479b87a0dc8cb0602268f9dca37ce", null ],
+    [ "aom_partition_features_t", "group__aom__encoder.html#ga2d4ad2535544500d48ac6ce6605cdf0c", null ],
+    [ "aom_partition_decision_t", "group__aom__encoder.html#gae9645fe5bb80ebb66970f85bdfc81d5f", null ],
+    [ "aom_partition_stats_t", "group__aom__encoder.html#gab9478e27301dfb5581f8bdf9efb40f3e", null ],
+    [ "aom_ext_part_status_t", "group__aom__encoder.html#ga4af3be5d269421964fc8b3e8681121dd", null ],
+    [ "aom_ext_part_create_model_fn_t", "group__aom__encoder.html#ga1a11077df0999ffba72a6fbfc8fe3331", null ],
+    [ "aom_ext_part_send_features_fn_t", "group__aom__encoder.html#ga8a09d2e568a6727f6dcfa189dcb64dc0", null ],
+    [ "aom_ext_part_get_decision_fn_t", "group__aom__encoder.html#gaf0c953c3c35d72df3e4bace498773be8", null ],
+    [ "aom_ext_part_send_partition_stats_fn_t", "group__aom__encoder.html#ga2c864d073d251c0ed7fe8d2b71c26417", null ],
+    [ "aom_ext_part_delete_model_fn_t", "group__aom__encoder.html#ga900ebe22eaa0f9296c4a876316fd4d82", null ],
+    [ "aom_ext_part_funcs_t", "group__aom__encoder.html#gac18e4b6e5fd6cb617a2674cf3de3f57e", null ],
     [ "AOM_SCALING_MODE", "group__aom__encoder.html#ga8f20643dbd528f92fc0ecd96d9726d09", null ],
     [ "aom_roi_map_t", "group__aom__encoder.html#gab64a195ea67269e704df30e39a22ca42", null ],
     [ "aom_active_map_t", "group__aom__encoder.html#gadbb2fdd04ce113cdf455a6ea49109d41", null ],
@@ -63,6 +182,14 @@ var group__aom__encoder =
     [ "aom_svc_layer_id_t", "group__aom__encoder.html#gacd5a13523326346771b2cf343cea96be", null ],
     [ "aom_svc_params_t", "group__aom__encoder.html#ga424f998c99e4a5584b60a41383af8dbe", null ],
     [ "aom_svc_ref_frame_config_t", "group__aom__encoder.html#gaf35292c5ec02cbfb58f06ec4889488e4", null ],
+    [ "aom_svc_ref_frame_comp_pred_t", "group__aom__encoder.html#gadc27bac35ec9960f115ff1d060c75eba", null ],
+    [ "aom_ext_part_decision_mode", "group__aom__encoder.html#ga7543b396ff2eef24d90b8edd094a9148", null ],
+    [ "AOM_EXT_PART_FEATURE_ID", "group__aom__encoder.html#ga241e62c4cf0d5f31f56e6be63df8e566", null ],
+    [ "aom_ext_part_status", "group__aom__encoder.html#ga4b28cbe3036a6f1c5753fa461facc192", [
+      [ "AOM_EXT_PART_OK", "group__aom__encoder.html#gga4b28cbe3036a6f1c5753fa461facc192aee3c61f0f0cf4c7338084ae7b8368aa0", null ],
+      [ "AOM_EXT_PART_ERROR", "group__aom__encoder.html#gga4b28cbe3036a6f1c5753fa461facc192a54c9174dd39c05769a23572ccebe8108", null ],
+      [ "AOM_EXT_PART_TEST", "group__aom__encoder.html#gga4b28cbe3036a6f1c5753fa461facc192a31af37ff758f79b82a0d4a65ba7aa0cf", null ]
+    ] ],
     [ "aome_enc_control_id", "group__aom__encoder.html#gae78dde67a6d78f332e9bdba0dde42db5", [
       [ "AOME_USE_REFERENCE", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a1fd179ef74229c4b1a438521eb4ab1e4", null ],
       [ "AOME_SET_ROI_MAP", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a274f8b560c2ecc4d03e553071e89a7a4", null ],
@@ -190,12 +317,18 @@ var group__aom__encoder =
       [ "AV1E_SET_GF_MIN_PYRAMID_HEIGHT", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a250c4c30488f4cd7108bf1c99515190e", null ],
       [ "AV1E_SET_VBR_CORPUS_COMPLEXITY_LAP", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a6810fa1bb5b3b9a58063006e1f894542", null ],
       [ "AV1E_GET_BASELINE_GF_INTERVAL", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a9c7e2ff5a2228bcd5c524c03ef60adc6", null ],
-      [ "AV1E_SET_ENABLE_DIAGONAL_INTRA", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a020292f1be3c8697766c6f190b1eef9e", null ]
+      [ "AV1E_SET_ENABLE_DIAGONAL_INTRA", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a020292f1be3c8697766c6f190b1eef9e", null ],
+      [ "AV1E_SET_DV_COST_UPD_FREQ", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a784231ebe03cdcd4ad77a2e3f7f0343e", null ],
+      [ "AV1E_SET_PARTITION_INFO_PATH", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5aa82ae17ed56d93d8f5901afbd2da172e", null ],
+      [ "AV1E_SET_EXTERNAL_PARTITION", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5ad041aa24f16d1d35c59ccbe4ff8ba420", null ],
+      [ "AV1E_SET_ENABLE_DIRECTIONAL_INTRA", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a54ad2c50072ecedbbcbe75df577afabd", null ],
+      [ "AV1E_SET_ENABLE_TX_SIZE_SEARCH", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5af9928b5094d367d21363784ddab11139", null ],
+      [ "AV1E_SET_SVC_REF_FRAME_COMP_PRED", "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a3bf579936cd7dc5e0a35e10e40a96ce9", null ]
     ] ],
     [ "aom_scaling_mode_1d", "group__aom__encoder.html#ga2a1791d26fca39303154f0f9ece3e295", null ],
     [ "aom_tune_content", "group__aom__encoder.html#ga801f5eb2cb93da19a2f347ae7a44166a", null ],
     [ "aom_timing_info_type_t", "group__aom__encoder.html#gad69c1d6aa10530991eeb1a3f0a818cba", null ],
     [ "aom_tune_metric", "group__aom__encoder.html#gaafd352cc596fab5388558950f8bbe739", null ],
-    [ "aom_codec_av1_cx", "group__aom__encoder.html#ga5b742eec203f55a95cc404f41c0166d8", null ],
+    [ "aom_codec_av1_cx", "group__aom__encoder.html#ga77adf3b7884b3619a4c5cbc236fe9de5", null ],
     [ "aom_codec_av1_cx_algo", "group__aom__encoder.html#ga18350b1c0642494e2b1a970104b2e8b9", null ]
 ];
\ No newline at end of file
