@@ -1,8 +1,10 @@
 var speed__features_8h =
 [
     [ "HIGH_LEVEL_SPEED_FEATURES", "structHIGH__LEVEL__SPEED__FEATURES.html", "structHIGH__LEVEL__SPEED__FEATURES" ],
+    [ "FIRST_PASS_SPEED_FEATURES", "structFIRST__PASS__SPEED__FEATURES.html", "structFIRST__PASS__SPEED__FEATURES" ],
     [ "SPEED_FEATURES", "structSPEED__FEATURES.html", "structSPEED__FEATURES" ],
     [ "HIGH_LEVEL_SPEED_FEATURES", "speed__features_8h.html#a803e1c508d00021beeeb1663d68d00b3", null ],
+    [ "FIRST_PASS_SPEED_FEATURES", "speed__features_8h.html#a99e299de837a3574beb3334509cfb2c9", null ],
     [ "SPEED_FEATURES", "speed__features_8h.html#a4a1fdb5ea677281c3604e8f99ef1d33b", null ],
     [ "CDEF_PICK_METHOD", "speed__features_8h.html#af0531e26369694f61a1d06bad088cb38", [
       [ "CDEF_FULL_SEARCH", "speed__features_8h.html#af0531e26369694f61a1d06bad088cb38a4f856e769829192cd8ec449baeec2012", null ],
