@@ -9,7 +9,6 @@ var structAV1__COMP =
     [ "coeff_buffer_pool", "structAV1__COMP.html#a5dd4bce670a858752380e59d8d8daaf9", null ],
     [ "common", "structAV1__COMP.html#a6c5ff3b8df382c108abbb290502d6242", null ],
     [ "oxcf", "structAV1__COMP.html#a683b6b6df2109e6301e61b07678cfa12", null ],
-    [ "no_show_fwd_kf", "structAV1__COMP.html#a7c4d3a3c6e0a58bd66659ea9428f4428", null ],
     [ "optimize_seg_arr", "structAV1__COMP.html#a391735210b755ea3e9de4777dd10965b", null ],
     [ "source", "structAV1__COMP.html#af506182c1bce3b944fcc72cd723e1bc7", null ],
     [ "last_source", "structAV1__COMP.html#a8a6dffc3949931c07ab86f18539c3ab8", null ],
@@ -18,14 +17,12 @@ var structAV1__COMP =
     [ "unscaled_last_source", "structAV1__COMP.html#a7f8997078cd563ed82f37e0b04e00b91", null ],
     [ "scaled_last_source", "structAV1__COMP.html#aedbfd57eeefc819431091d2be25cab11", null ],
     [ "unfiltered_source", "structAV1__COMP.html#a91905e3eeee006840918bd3aaf93bab7", null ],
-    [ "tpl_data", "structAV1__COMP.html#a6e825c9a9b758dcf18a88abba2a2634f", null ],
+    [ "skip_tpl_setup_stats", "structAV1__COMP.html#a060badd4366bf3a270597d89e0b1a6cb", null ],
     [ "tf_ctx", "structAV1__COMP.html#a523f84e04ce020b292bf61b256ae6846", null ],
-    [ "partition_search_skippable_frame", "structAV1__COMP.html#a1970c14253481405661819eff5d1ee8b", null ],
     [ "force_intpel_info", "structAV1__COMP.html#a5733fdde1a696d314fc0ce412b91f8fb", null ],
     [ "scaled_ref_buf", "structAV1__COMP.html#a62bdce36b2cdeb4e2a9a5c03b8820afc", null ],
     [ "last_show_frame_buf", "structAV1__COMP.html#a9c4957c740b2c95513d7af9ed2999211", null ],
     [ "refresh_frame", "structAV1__COMP.html#af6b2d893f5ad9321fb516d69c18e72d2", null ],
-    [ "fb_of_context_type", "structAV1__COMP.html#ad5b52eba2d1441c4f61280550daec2a6", null ],
     [ "ext_flags", "structAV1__COMP.html#a473c02eb07f88a9bcebeaece5c5fe0cc", null ],
     [ "last_frame_uf", "structAV1__COMP.html#ae0e804c9201665f126ceb0c693dd1d25", null ],
     [ "trial_frame_rst", "structAV1__COMP.html#ad780d3cebefa7f76b212c0cb8de3f140", null ],
@@ -45,15 +42,8 @@ var structAV1__COMP =
     [ "enc_seg", "structAV1__COMP.html#a4a7cab775d531af4ba9f1eaeccd34a58", null ],
     [ "cyclic_refresh", "structAV1__COMP.html#a11fd423b6ca0324129bec05b69f80162", null ],
     [ "active_map", "structAV1__COMP.html#a26df07c85b5dc42b04519f478d90e97f", null ],
-    [ "fn_ptr", "structAV1__COMP.html#a1cce1c3de12bbdff13d6259674844217", null ],
-    [ "twopass", "structAV1__COMP.html#ad1116367906faf7fa459b6da3caa49c6", null ],
-    [ "gf_group", "structAV1__COMP.html#a754ed09bfc79115e4b1e9429cc6a831f", null ],
     [ "gf_frame_index", "structAV1__COMP.html#a630c1c37c763287c2a68cb64be0bbc65", null ],
-    [ "gf_state", "structAV1__COMP.html#a965469435b52bc9bf4a05dac08594a54", null ],
     [ "ref_buffer_stack", "structAV1__COMP.html#aafef31df0c1b5e5d6db360eda9ca9f2e", null ],
-    [ "alt_ref_buffer", "structAV1__COMP.html#a8f4fa21f95f78e3d6f98f18879f326ef", null ],
-    [ "show_existing_alt_ref", "structAV1__COMP.html#a6c88a92e7fb389109e0b3021320a21cf", null ],
-    [ "b_calculate_psnr", "structAV1__COMP.html#a2f66a481acd41b4c3f85fc50cea5f0ef", null ],
     [ "droppable", "structAV1__COMP.html#a9c014587b95805c0d3d3196b3108122e", null ],
     [ "frame_info", "structAV1__COMP.html#a98a22afbd13b9c7a14a1ad51d1bdf415", null ],
     [ "frame_index_set", "structAV1__COMP.html#a61ca5f788df7db66a40f902f8929bf3f", null ],
@@ -65,7 +55,6 @@ var structAV1__COMP =
     [ "token_info", "structAV1__COMP.html#a28956d8f775c173f7bd76e92a459853c", null ],
     [ "vaq_refresh", "structAV1__COMP.html#a066a671f4995bbcf08b2110105391195", null ],
     [ "vbp_info", "structAV1__COMP.html#a8431a87c6d3ed7cacf1d1d4b53eb15b1", null ],
-    [ "frame_probs", "structAV1__COMP.html#a41d8b5de686a452db54290ee42a887de", null ],
     [ "mt_info", "structAV1__COMP.html#a81e0bda4dd2dff128613be4c1cd186fb", null ],
     [ "existing_fb_idx_to_show", "structAV1__COMP.html#a8e29879e2541a075abb94510dc698007", null ],
     [ "intrabc_used", "structAV1__COMP.html#a79d3369ac3e0d4a9461c133a285a417f", null ],
@@ -76,24 +65,27 @@ var structAV1__COMP =
     [ "interp_search_flags", "structAV1__COMP.html#abdbb43940e22262999e72bccf44fb1a2", null ],
     [ "use_screen_content_tools", "structAV1__COMP.html#a4ca11c36b5bab99d6240752ff37a89a3", null ],
     [ "is_screen_content_type", "structAV1__COMP.html#ab86c618addbf983a08da80ae806d03f3", null ],
-    [ "level_params", "structAV1__COMP.html#abe2b6fdd6c2f0d85c1f0fb42bc437407", null ],
+    [ "frame_header_count", "structAV1__COMP.html#a9aea0ecc72af0b304c33dae392a884f6", null ],
     [ "deltaq_used", "structAV1__COMP.html#a26de3eb8d7f7d75083c364f754507562", null ],
     [ "ref_frame_dist_info", "structAV1__COMP.html#ae17f8b5096955a0bb3a553c719c362e3", null ],
-    [ "tpl_rdmult_scaling_factors", "structAV1__COMP.html#aaa416562780c42ed8fbc439a8e033f59", null ],
-    [ "tpl_sb_rdmult_scaling_factors", "structAV1__COMP.html#a46c50c95a0432f2fd1fc413b2c79d91d", null ],
     [ "ssim_rdmult_scaling_factors", "structAV1__COMP.html#a3b3aa4af7d870ee595dbe487c37d3950", null ],
-    [ "use_svc", "structAV1__COMP.html#aa8a27fad3e581937e6cb0280aced79e0", null ],
     [ "svc", "structAV1__COMP.html#af8128359d98cbd69def126adb45965ef", null ],
-    [ "lap_enabled", "structAV1__COMP.html#a308e3c44906ce63ff9603657fe83424f", null ],
     [ "compressor_stage", "structAV1__COMP.html#a79be536fcf6a3d04be9c6c7a838e2421", null ],
-    [ "mv_stats", "structAV1__COMP.html#aefe4d284d22f10945fe1c18cb2a095a4", null ],
     [ "last_frame_type", "structAV1__COMP.html#a0ac239b9892a1799eda25582b402430e", null ],
     [ "num_tg", "structAV1__COMP.html#a3f3c93cc1e7ce42de06a8aae22397fcf", null ],
     [ "superres_mode", "structAV1__COMP.html#a9d47cd6cfb938137c22514c510a946b5", null ],
     [ "firstpass_data", "structAV1__COMP.html#acac975b1b40d779f5475ea38b852a9f6", null ],
     [ "noise_estimate", "structAV1__COMP.html#afb2b64c6890885dbc8ebf1b1e49941e0", null ],
     [ "consec_zero_mv", "structAV1__COMP.html#a044d3dfed6b8921cd7d74dee128d987e", null ],
-    [ "frames_left", "structAV1__COMP.html#ac96425c3c9885b3a88f6c808b8bded0c", null ],
     [ "fp_block_size", "structAV1__COMP.html#ad2c0908b11b789a2df0a90e563a433ea", null ],
-    [ "sb_counter", "structAV1__COMP.html#ab73f758bfa8d3c1edea9981ecfe4ddf0", null ]
+    [ "sb_counter", "structAV1__COMP.html#ab73f758bfa8d3c1edea9981ecfe4ddf0", null ],
+    [ "available_bs_size", "structAV1__COMP.html#a30c0d235c498e05247be568b93b98081", null ],
+    [ "ext_part_controller", "structAV1__COMP.html#a3a1d855f2d5488284688433c8d7bdc86", null ],
+    [ "mb_weber_stats", "structAV1__COMP.html#a284a0ce79fc6c8e18d3b8c592b0d6da9", null ],
+    [ "weber_bsize", "structAV1__COMP.html#ab96a678fa569c136c2ed087b68a2d401", null ],
+    [ "norm_wiener_variance", "structAV1__COMP.html#aa7f83fb36f70ef378393873e41a26f7e", null ],
+    [ "mb_delta_q", "structAV1__COMP.html#a063d56623dcab7e26974036303ef012e", null ],
+    [ "is_dropped_frame", "structAV1__COMP.html#ad7a2fbeb7e11ff525044f82b73d1f56b", null ],
+    [ "twopass_frame", "structAV1__COMP.html#afc1e293e4ae3b459e8f8d785540f6257", null ],
+    [ "third_pass_ctx", "structAV1__COMP.html#a7f8eb526cc0e962a3f3500bff283db27", null ]
 ];
\ No newline at end of file
