@@ -2,8 +2,6 @@ var structMultiThreadInfo =
 [
     [ "num_workers", "structMultiThreadInfo.html#a6a9afb33f804f3d05a95c2c6293876b4", null ],
     [ "num_mod_workers", "structMultiThreadInfo.html#a4cfb092072ea63dba9687b7c01710b91", null ],
-    [ "fp_mt_buf_init_done", "structMultiThreadInfo.html#a8f1b23ab38df496cd8aa536a97a2a80a", null ],
-    [ "enc_mt_buf_init_done", "structMultiThreadInfo.html#a3cce3d39ef6b6f7b29bc2efccb41072f", null ],
     [ "workers", "structMultiThreadInfo.html#a8cb3f9e110b3a6da79df5a6511fad62c", null ],
     [ "tile_thr_data", "structMultiThreadInfo.html#a2b42428a58f2156b1de62ce86433f8fc", null ],
     [ "row_mt_enabled", "structMultiThreadInfo.html#aa36d5dc7aedc2878868367b5855f6882", null ],
@@ -11,7 +9,9 @@ var structMultiThreadInfo =
     [ "tpl_row_mt", "structMultiThreadInfo.html#a38989d63e9269a85134d00852df10c94", null ],
     [ "lf_row_sync", "structMultiThreadInfo.html#a4bf3911993b18169add61be10b6316cf", null ],
     [ "lr_row_sync", "structMultiThreadInfo.html#a26e9e2c6fff05ed599cca17ad531cf33", null ],
+    [ "pack_bs_sync", "structMultiThreadInfo.html#a3f61c23bcf10b729b004cdd659de716f", null ],
     [ "gm_sync", "structMultiThreadInfo.html#ad464c86982e3a1b95043563537dc352c", null ],
     [ "tf_sync", "structMultiThreadInfo.html#ac9e21840e1d3d46bb90468002563a6d1", null ],
-    [ "cdef_sync", "structMultiThreadInfo.html#a4c5a8262265dc49360e838ca94774482", null ]
+    [ "cdef_sync", "structMultiThreadInfo.html#a4c5a8262265dc49360e838ca94774482", null ],
+    [ "cdef_worker", "structMultiThreadInfo.html#a1d6db43c99a605ffc0ef85bf473326b9", null ]
 ];
\ No newline at end of file
